@@ -6,6 +6,8 @@ var credits =
                               ],
         [ "Christian Aigner", "Misc > Draw > Dovetail from 2 Points<br>"
                               ],
+        [ "CVH",              "Misc > Script Examples > Mathematics > FlexPainter<br>"
+                              ],
         [ "Matfie",           "Gear generator library item \"InvoluteSpur\"<br>"
                               ],
         [ "Matthias Melcher", "Drawing box joint lines<br>" +
@@ -42,6 +44,8 @@ var credits =
                               "Info > Arc/Circle/Ellipse Area<br>" +
                               "Custom linetype support, loading .lin files<br>"
                               ],
+        [ "Stephen Casner",   "Misc > Select > By Color"
+                              ],
         [ "Tamas Tevesz",     "Port to FreeBSD<br>" +
                               "Various improvements and fixes<br>"
                               ],
@@ -51,12 +55,12 @@ var credits =
     [
         qsTr("Translations"),
         //[ "Wang Zhen Zhe",     "Chinese (zh_CN) translation." ],
-        [ "Petr Zgraja, fialot", "Czech (cs) translation" ],
+        [ "Petr Zgraja, 'fialot'", "Czech (cs) translation" ],
         [ "Andrew Mustun",       "Dutch (nl) translation" ],
-        [ "Timo Seppola",        "Finnish (fi) translation" ],
+        [ "Timo Seppola, Jarmo", "Finnish (fi) translation" ],
         [ "Andrew Mustun",       "German (de) translation" ],
         [ "Fabrizio Margini",    "Italian (it) translation" ],
-        [ "Tanaka Hidemune",     "Japanese (ja) translation and user reference manual" ],
+        [ "Tanaka Hidemune",     "Japanese (ja) translation and Japanese user reference manual" ],
         [ "Евгений, AlexL",      "Russian (ru) translation" ],
         [ "Ján Jamriška",        "Slovak (sk) translation" ],
         [ "Miha ('miharix')",    "Slovenian (sl) translation" ],
